\DeclareAtomName{1}{Wasserstoff}
\DeclareAtomName{2}{Helium}
\DeclareAtomName{3}{Lithium}
\DeclareAtomName{4}{Beryllium}
\DeclareAtomName{5}{Bor}
\DeclareAtomName{6}{Kohlenstoff}
\DeclareAtomName{7}{Stickstoff}
\DeclareAtomName{8}{Souerstoff}
\DeclareAtomName{9}{Fluor}
\DeclareAtomName{10}{Neon}
\DeclareAtomName{11}{Natrium}
\DeclareAtomName{12}{Magnesium}
\DeclareAtomName{13}{Aluminium}
\DeclareAtomName{14}{Silicium}
\DeclareAtomName{15}{Phosphor}
\DeclareAtomName{16}{Schwefel}
\DeclareAtomName{17}{Chlor}
\DeclareAtomName{18}{Argon}
\DeclareAtomName{19}{Kalium}
\DeclareAtomName{20}{Calcium}
\DeclareAtomName{21}{Scandium}
\DeclareAtomName{22}{Titan}
\DeclareAtomName{23}{Vanadium}
\DeclareAtomName{24}{Chrom}
\DeclareAtomName{25}{Mangan}
\DeclareAtomName{26}{Eisen}
\DeclareAtomName{27}{Cobalt}
\DeclareAtomName{28}{Nickel}
\DeclareAtomName{29}{Kupfer}
\DeclareAtomName{30}{Zink}
\DeclareAtomName{31}{Gallium}
\DeclareAtomName{32}{Germanium}
\DeclareAtomName{33}{Arsen}
\DeclareAtomName{34}{Selen}
\DeclareAtomName{35}{Brom}
\DeclareAtomName{36}{Krypton}
\DeclareAtomName{37}{Rubidium}
\DeclareAtomName{38}{Strontium}
\DeclareAtomName{39}{Yttrium}
\DeclareAtomName{40}{Zirconium}
\DeclareAtomName{41}{Niobium}
\DeclareAtomName[Molybdaen]{42}{Molybd\"{a}n}
\DeclareAtomName{43}{Technetium}
\DeclareAtomName{44}{Ruthenium}
\DeclareAtomName{45}{Rhodium}
\DeclareAtomName{46}{Palladium}
\DeclareAtomName{47}{Silber}
\DeclareAtomName{48}{Cadmium}
\DeclareAtomName{49}{Indium}
\DeclareAtomName{50}{Zinn}
\DeclareAtomName{51}{Antimon}
\DeclareAtomName{52}{Tellur}
\DeclareAtomName{53}{Iod}
\DeclareAtomName{54}{Xenon}
\DeclareAtomName[Caesium]{55}{C\"{a}sium}
\DeclareAtomName{56}{Barium}
\DeclareAtomName{57}{Lanthan}
\DeclareAtomName{58}{Cer}
\DeclareAtomName{59}{Praseodym}
\DeclareAtomName{60}{Neodym}
\DeclareAtomName{61}{Promethium}
\DeclareAtomName{62}{Samarium}
\DeclareAtomName{63}{Europium}
\DeclareAtomName{64}{Gadolinium}
\DeclareAtomName{65}{Terbium}
\DeclareAtomName{66}{Dysprosium}
\DeclareAtomName{67}{Holmium}
\DeclareAtomName{68}{Erbium}
\DeclareAtomName{69}{Thulium}
\DeclareAtomName{70}{Ytterbium}
\DeclareAtomName{71}{Lutetium}
\DeclareAtomName{72}{Hafnium}
\DeclareAtomName{73}{Tantal}
\DeclareAtomName{74}{Wolfram}
\DeclareAtomName{75}{Rhenium}
\DeclareAtomName{76}{Osmium}
\DeclareAtomName{77}{Iridium}
\DeclareAtomName{78}{Platin}
\DeclareAtomName{79}{Gold}
\DeclareAtomName{80}{Quecksilber}
\DeclareAtomName{81}{Thallium}
\DeclareAtomName{82}{Blei}
\DeclareAtomName{83}{Bismut}
\DeclareAtomName{84}{Polonium}
\DeclareAtomName{85}{Astat}
\DeclareAtomName{86}{Radon}
\DeclareAtomName{87}{Francium}
\DeclareAtomName{88}{Radium}
\DeclareAtomName{89}{Actinium}
\DeclareAtomName{90}{Thorium}
\DeclareAtomName{91}{Protactinium}
\DeclareAtomName{92}{Uran}
\DeclareAtomName{93}{Neptunium}
\DeclareAtomName{94}{Plutonium}
\DeclareAtomName{95}{Americium}
\DeclareAtomName{96}{Curium}
\DeclareAtomName{97}{Berkelium}
\DeclareAtomName{98}{Californium}
\DeclareAtomName{99}{Einsteinium}
\DeclareAtomName{100}{Fermium}
\DeclareAtomName{101}{Mendelevium}
\DeclareAtomName{102}{Nobelium}
\DeclareAtomName{103}{Lawrencium}
\DeclareAtomName{104}{Rutherfordium}
\DeclareAtomName{105}{Dubnium}
\DeclareAtomName{106}{Seaborgium}
\DeclareAtomName{107}{Bohrium}
\DeclareAtomName{108}{Hassium}
\DeclareAtomName{109}{Meitnerium}
\DeclareAtomName{110}{Darmstadtium}
\DeclareAtomName{111}{Roentgenium}
\DeclareAtomName{112}{Copernicium}

\endinput
